@@ -1,7 +1,9 @@
 /* powers-of-10 constants */
-/* some constants here are rounded down so >= comparisons work better */
+/* constants here are rounded down so >= comparisons work better */
 
-#define POWER_27  1e+27                  /*   0x1.9d971e4fe8402p+89  */
+#define POWER_33  0x1.8a6e32246c99bp+109 /*   0x1.8a6e32246c99cp+109 */
+#define POWER_30  0x1.93e5939a08ce9p+99  /* Q 0x1.93e5939a08ceap+99  */
+#define POWER_27  0x1.9d971e4fe8401p+89  /* R 0x1.9d971e4fe8402p+89  */
 #define POWER_24  0x1.a784379d99db3p+79  /* Y 0x1.a784379d99db4p+79  */
 #define POWER_21  0x1.b1ae4d6e2ef4fp+69  /* Z 0x1.b1ae4d6e2ef5p+69   */
 #define POWER_18  0x1.bc16d674ec7ffp+59  /* E 0x1.bc16d674ec8p+59    */
@@ -13,10 +15,12 @@
 #define POWER_0   0x1.fffffffffffffp-1   /*   0x1p+0                 */
 #define POWER__3  0x1.0624dd2f1a9fbp-10  /* m 0x1.0624dd2f1a9fcp-10  */
 #define POWER__6  0x1.0c6f7a0b5ed8cp-20  /* µ 0x1.0c6f7a0b5ed8dp-20  */
-#define POWER__9  1e-09                  /* n 0x1.12e0be826d695p-30  */
-#define POWER__12 0x1.19799812dea10p-40  /* p 0x1.19799812dea11p-40  */
-#define POWER__15 1e-15                  /* f 0x1.203af9ee75616p-50  */
+#define POWER__9  0x1.12e0be826d694p-30  /* n 0x1.12e0be826d695p-30  */
+#define POWER__12 0x1.19799812dea1p-40   /* p 0x1.19799812dea11p-40  */
+#define POWER__15 0x1.203af9ee75615p-50  /* f 0x1.203af9ee75616p-50  */
 #define POWER__18 0x1.2725dd1d243abp-60  /* a 0x1.2725dd1d243acp-60  */
 #define POWER__21 0x1.2e3b40a0e9b4ep-70  /* z 0x1.2e3b40a0e9b4fp-70  */
 #define POWER__24 0x1.357c299a88ea6p-80  /* y 0x1.357c299a88ea7p-80  */
-#define POWER__27 0x1.3ce9a36f23c0fp-90  /*   0x1.3ce9a36f23c1p-90   */
+#define POWER__27 0x1.3ce9a36f23c0fp-90  /* r 0x1.3ce9a36f23c1p-90   */
+#define POWER__30 0x1.4484bfeebc29fp-100 /* q 0x1.4484bfeebc2ap-100  */
+#define POWER__33 0x1.4c4e977ba1f5bp-110 /*   0x1.4c4e977ba1f5cp-110 */
