@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -30,6 +31,10 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
+
 #ifndef YY_YYUNIT_UNITPARSE_TAB_H_INCLUDED
 # define YY_YYUNIT_UNITPARSE_TAB_H_INCLUDED
 /* Debug traces.  */
@@ -48,52 +53,47 @@
 extern int yyunitdebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYUNITTOKENTYPE
 # define YYUNITTOKENTYPE
   enum yyunittokentype
   {
-    DOUBLE = 258,
-    UNIT_SHIFT = 259,
-    EXPONENT = 260,
-    SUPER_SIGN = 261,
-    SUPER = 262,
-    ERR = 263,
-    UMINUS = 264
+    YYUNITEMPTY = -2,
+    YYUNITEOF = 0,                 /* "end of file"  */
+    YYUNITerror = 256,             /* error  */
+    YYUNITUNDEF = 257,             /* "invalid token"  */
+    DOUBLE = 258,                  /* DOUBLE  */
+    UNIT_SHIFT = 259,              /* UNIT_SHIFT  */
+    EXPONENT = 260,                /* EXPONENT  */
+    SUPER_SIGN = 261,              /* SUPER_SIGN  */
+    SUPER = 262,                   /* SUPER  */
+    FUNCTION = 263,                /* FUNCTION  */
+    ERR = 264,                     /* ERR  */
+    UMINUS = 265                   /* UMINUS  */
   };
+  typedef enum yyunittokentype yyunittoken_kind_t;
 #endif
 
 /* Value type.  */
 #if ! defined YYUNITSTYPE && ! defined YYUNITSTYPE_IS_DECLARED
-
 union YYUNITSTYPE
 {
+  UnitShift UNIT_SHIFT;                    /* UNIT_SHIFT  */
+  UnitShift input;                         /* input  */
+  UnitShift expr;                          /* expr  */
+  UnitShift simple_expr;                   /* simple_expr  */
+  double DOUBLE;                           /* DOUBLE  */
+  double number;                           /* number  */
+  enum parser_function FUNCTION;           /* FUNCTION  */
+  int EXPONENT;                            /* EXPONENT  */
+  int SUPER_SIGN;                          /* SUPER_SIGN  */
+  int SUPER;                               /* SUPER  */
+  int exponent;                            /* exponent  */
+  int super;                               /* super  */
+
+#line 95 "unitparse.tab.h"
 
-  /* UNIT_SHIFT  */
-  UnitShift UNIT_SHIFT;
-  /* input  */
-  UnitShift input;
-  /* expr  */
-  UnitShift expr;
-  /* simple_expr  */
-  UnitShift simple_expr;
-  /* DOUBLE  */
-  double DOUBLE;
-  /* number  */
-  double number;
-  /* EXPONENT  */
-  int EXPONENT;
-  /* SUPER_SIGN  */
-  int SUPER_SIGN;
-  /* SUPER  */
-  int SUPER;
-  /* exponent  */
-  int exponent;
-  /* super  */
-  int super;
-#line 95 "unitparse.tab.h" /* yacc.c:1909  */
 };
-
 typedef union YYUNITSTYPE YYUNITSTYPE;
 # define YYUNITSTYPE_IS_TRIVIAL 1
 # define YYUNITSTYPE_IS_DECLARED 1
@@ -102,6 +102,8 @@ typedef union YYUNITSTYPE YYUNITSTYPE;
 
 extern YYUNITSTYPE yyunitlval;
 
+
 int yyunitparse (void);
 
+
 #endif /* !YY_YYUNIT_UNITPARSE_TAB_H_INCLUDED  */
